@@ -35,10 +35,10 @@
   name tracks current etc)
 
 (cl-defstruct listen-track
-  filename artist title album number genre length date rating etc)
+  filename artist title album number genre duration date rating etc)
 
 (cl-defmethod cl-print-object ((track listen-track) stream)
-  (princ (listen-track-filename track) stream))
+  (prin1 (listen-track-filename track) stream))
 
 ;;;; Variables
 
@@ -50,7 +50,7 @@
 ;;;; Faces
 
 (defgroup listen-faces nil
-  "Faces."
+  "Faces used by `listen'."
   :group 'listen)
 
 (defface listen-artist '((t :inherit font-lock-variable-name-face))
@@ -77,6 +77,10 @@
   (or listen-player
       (setf listen-player (make-listen-player-vlc))))
 
+(defun listen-format-seconds (seconds)
+  "Return SECONDS formatted as an hour:minute:second-style duration."
+  (format-seconds "%h:%z%.2m:%.2s" seconds))
+
 ;;;; Methods
 
 (cl-defmethod listen--running-p ((player listen-player))
