@@ -30,7 +30,9 @@
 (require 'mpc)
 
 (defvar listen-directory)
+(defvar crm-separator)
 
+;;;###autoload
 (cl-defun listen-mpd-completing-read (&key (tag 'file) select-tag-p)
   "Return files selected from MPD library.
 Searches by TAG; or if SELECT-TAG-P, tag is selected with
@@ -114,13 +116,17 @@ completion."
            (prompt (pcase-exhaustive tag
                      ('file "MPC Search (track): ")
                      (_ (format "MPC Search (%s): " tag))))
-           (result (completing-read prompt #'collection nil))
+           (result (let ((crm-separator ";"))
+                     (ensure-list (completing-read-multiple prompt #'collection nil))))
            (result (pcase tag
-                     ("any" result)
-                     (_ (mapcar (lambda (row)
-                                  (alist-get 'file row))
-                                (mpc-proc-buf-to-alists
-                                 (mpc-proc-cmd (list "find" (symbol-name tag) result))))))))
+                     ('any result)
+                     (_ (flatten-list
+                         (mapcar (lambda (result)
+                                   (mapcar (lambda (row)
+                                             (alist-get 'file row))
+                                           (mpc-proc-buf-to-alists
+                                            (mpc-proc-cmd (list "find" (symbol-name tag) result)))))
+                                 result))))))
       (mapcar (lambda (filename)
                 (expand-file-name filename (or mpc-mpd-music-directory listen-directory)))
               result))))
